pub fn image_memory_barrier<'f1>() -> ImageMemoryBarrierBuilder<'f1>Expand description
Write a pipeline barrier to the command buffer to transition the image layout.
pub fn image_memory_barrier<'f1>() -> ImageMemoryBarrierBuilder<'f1>Write a pipeline barrier to the command buffer to transition the image layout.